@@ -210,9 +210,10 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT" ) ) );
 
   const QString textDir = parameterAsString( parameters, QStringLiteral( "OUTPUT_TEXT_DIR" ), context );
-  if ( ! textDir.isEmpty() &&
-       ! QDir( textDir ).exists() )
-    throw QgsProcessingException( QObject::tr( "The text output directory does not exist" ) );
+  if ( !textDir.isEmpty() && !QDir().mkpath( textDir ) )
+  {
+    throw QgsProcessingException( QObject::tr( "Failed to create the text output directory" ) );
+  }
 
   QgsDistanceArea da = QgsDistanceArea();
   da.setSourceCrs( source->sourceCrs(), context.transformContext() );
@@ -331,7 +332,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
     if ( !sink->addFeature( outputFeature, QgsFeatureSink::FastInsert ) )
       throw QgsProcessingException( writeFeatureError( sink.get(), parameters, QStringLiteral( "OUTPUT" ) ) );
 
-    if ( ! textDir.isEmpty() )
+    if ( !textDir.isEmpty() )
     {
       const QString filename = QDir( textDir ).filePath( hit.key().toString() + QString( ".txt" ) );
       QFile textFile( filename );
@@ -364,6 +365,10 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
   QVariantMap outputs;
   outputs.insert( QStringLiteral( "OUTPUT" ), dest );
   outputs.insert( QStringLiteral( "NUM_PATHS" ), pathCount );
+  if ( !textDir.isEmpty() )
+  {
+    outputs.insert( QStringLiteral( "OUTPUT_TEXT_DIR" ), textDir );
+  }
   return outputs;
 }
 
