@@ -713,7 +713,7 @@ void QgsDataSourceUri::setEncodedUri( const QByteArray &uri )
   const auto constQueryItems = query.queryItems();
   for ( const QPair<QString, QString> &item : constQueryItems )
   {
-    if ( !item.first.startsWith( QgsHttpHeaders::PARAM_PREFIX ) )
+    if ( !item.first.startsWith( QgsHttpHeaders::PARAM_PREFIX ) && item.first != QgsHttpHeaders::KEY_REFERER )
     {
       if ( item.first == QLatin1String( "username" ) )
         mUsername = query.queryItemValue( QStringLiteral( "username" ), QUrl::ComponentFormattingOption::FullyDecoded );
@@ -729,7 +729,9 @@ void QgsDataSourceUri::setEncodedUri( const QByteArray &uri )
 
 void QgsDataSourceUri::setEncodedUri( const QString &uri )
 {
-  setEncodedUri( uri.toLatin1() );
+  QUrl url;
+  url.setQuery( uri );
+  setEncodedUri( url.query( QUrl::EncodeUnicode ).toLatin1() );
 }
 
 QString QgsDataSourceUri::quotedTablename() const
