@@ -61,6 +61,7 @@ class TestQgsVectorTileLayer : public QgsTest
     void test_render();
     void test_render_withClip();
     void test_labeling();
+    void test_labeling_clone();
 
     void testMbtilesProviderMetadata();
     void test_relativePathsMbTiles();
@@ -220,6 +221,17 @@ void TestQgsVectorTileLayer::test_labeling()
   QVERIFY( res2 );
 }
 
+void TestQgsVectorTileLayer::test_labeling_clone()
+{
+  QgsVectorTileBasicLabeling *labeling = new QgsVectorTileBasicLabeling;
+  mLayer->setLabeling( labeling );
+
+  std::unique_ptr<QgsVectorTileLayer> vtlClone;
+  vtlClone.reset( mLayer->clone() );
+  QVERIFY( vtlClone->isValid() );
+  QVERIFY( vtlClone->labeling() != nullptr );
+}
+
 void TestQgsVectorTileLayer::testMbtilesProviderMetadata()
 {
   QgsProviderMetadata *vectorTileMetadata = QgsProviderRegistry::instance()->providerMetadata( "mbtilesvectortiles" );
